@@ -1,17 +1,15 @@
-import os
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = "hide"
 from pygame import Surface, Rect
 
-from typing import Sequence, List, Tuple, Optional, FrozenSet, Any
+from typing import Iterable, List, Tuple, Optional, FrozenSet, Any
 from weakref import ref
 
 
 class Recurface:
     def __init__(
             self, surface: Optional[Surface] = None, parent: Optional["Recurface"] = None,
-            position: Optional[Sequence[float]] = None, priority: Any = None):
+            position: Optional[Tuple[float, float]] = None, priority: Any = None):
         self.__surface = surface  # Must hold a valid pygame Surface in order to successfully render
-        self.__render_position = list(position) if position else None  # (x, y) to render to in the containing Surface
+        self.__render_position = list(position) if position else None  # (x, y) to render at in the containing Surface
         self.__render_priority = priority  # Determines how recurfaces at the same nesting level are layered on screen
 
         self.__rect = None
@@ -37,11 +35,11 @@ class Recurface:
         self.__surface = value
 
     @property
-    def render_position(self) -> Optional[Tuple[float]]:
+    def render_position(self) -> Optional[Tuple[float, float]]:
         return tuple(self.__render_position) if self.__render_position else None
 
     @render_position.setter
-    def render_position(self, value: Optional[Sequence[float]]):
+    def render_position(self, value: Optional[Tuple[float, float]]):
         if self.__render_position is None or value is None:
             if self.__render_position == value:
                 return  # Position is already correctly set
@@ -119,8 +117,18 @@ class Recurface:
         return frozenset(self.__child_recurfaces)
 
     @property
-    def ordered_child_recurfaces(self) -> Tuple["Recurface"]:
-        return self.__ordered_child_recurfaces
+    def ordered_child_recurfaces(self) -> Tuple["Recurface", ...]:
+        """
+        Returns the child recurfaces linked to this Recurface object, sorted by their `.render_priority`.
+        If the child recurfaces' priorities cannot be compared
+        (this will be the case if any of the recurfaces have the default priority of None),
+        the relevant TypeError will be raised
+        """
+
+        if type(self.__ordered_child_recurfaces) is TypeError:
+            raise self.__ordered_child_recurfaces
+        else:
+            return self.__ordered_child_recurfaces
 
     @property
     def render_priority(self) -> Any:
@@ -151,7 +159,7 @@ class Recurface:
 
             child.parent_recurface = None
 
-    def move_render_position(self, x_offset: float = 0, y_offset: float = 0) -> Tuple[float]:
+    def move_render_position(self, x_offset: float = 0, y_offset: float = 0) -> Tuple[float, float]:
         """
         Adds the provided offset values to the recurface's current position.
         Returns a tuple representing the updated .position.
@@ -164,7 +172,7 @@ class Recurface:
 
         return self.render_position
 
-    def add_update_rects(self, rects: Sequence[Optional[Rect]], update_position: bool = False) -> None:
+    def add_update_rects(self, rects: Iterable[Optional[Rect]], update_position: bool = False) -> None:
         """
         Stores the provided pygame rects to be returned by this recurface on the next render() call.
         Used internally to handle removing child objects.
@@ -211,8 +219,13 @@ class Recurface:
             raise ValueError(".surface does not contain a valid pygame Surface to render")
         surface_working = self.surface.copy()
 
+        try:
+            child_recurfaces = self.ordered_child_recurfaces
+        except TypeError:
+            child_recurfaces = self.child_recurfaces
+
         child_rects = []
-        for child in self.ordered_child_recurfaces:  # Render all child objects in the correct order and collect returned Rects
+        for child in child_recurfaces:  # Render all child objects in the correct order and collect returned Rects
             rects = child.render(surface_working)
 
             for rect in rects:
@@ -274,6 +287,9 @@ class Recurface:
         self.__rect_additional = []
 
     def _calculate_ordered_child_recurfaces(self) -> None:
-        self.__ordered_child_recurfaces = tuple(
-            sorted(self.__child_recurfaces, key=lambda recurface: recurface.render_priority)
-        )
+        try:
+            self.__ordered_child_recurfaces = tuple(
+                sorted(self.__child_recurfaces, key=lambda recurface: recurface.render_priority)
+            )
+        except TypeError as ex:  # Unable to sort recurfaces due to non-comparable priority values
+            self.__ordered_child_recurfaces = ex
